@@ -25,7 +25,7 @@ from dataclasses_json import dataclass_json
 
 from tradingstrategy.chain import ChainId
 from tradingstrategy.token import Token
-from tradingstrategy.exchange import ExchangeUniverse, Exchange
+from tradingstrategy.exchange import ExchangeUniverse, Exchange, ExchangeType
 from tradingstrategy.stablecoin import ALL_STABLECOIN_LIKE
 from tradingstrategy.types import NonChecksummedAddress, BlockNumber, UNIXTimestamp, BasisPoint, PrimaryKey
 from tradingstrategy.utils.columnar import iterate_columnar_dicts
@@ -44,20 +44,6 @@ class DuplicatePair(Exception):
     """Found multiple trading pairs for the same naive lookup."""
 
 
-class PairType(enum.Enum):
-    """What kind of an decentralised exchange, AMM or other the pair is trading on.
-
-    Note that each type can have multiple implementations.
-    For example QuickSwap, Sushi and Pancake are all Uniswap v2 types.
-    """
-
-    #: Uniswap v2 style exchange
-    uniswap_v2 = "uni_v2"
-
-    #: Uniswap v3 style exchange
-    uniswap_v3 = "uni_v3"
-
-
 @dataclass_json
 @dataclass
 class DEXPair:
@@ -125,9 +111,6 @@ class DEXPair:
     #: In the case of Uniswap this is the pair (pool) address.
     address: NonChecksummedAddress
 
-    #: What kind of exchange this pair is on
-    dex_type: PairType
-
     #: Token pair contract address on-chain.
     #: Lowercase, non-checksummed.
     token0_address: str
@@ -144,6 +127,9 @@ class DEXPair:
     #: ERC-20 contracst are not guaranteed to have this data.
     token1_symbol: Optional[str]
 
+    #: What kind of exchange this pair is on
+    dex_type: Optional[ExchangeType] = None
+
     #: Naturalised base and quote token.
     #: Uniswap may present the pair in USDC-WETH or WETH-USDC order based on the token address order.
     #: However we humans always want the quote token to be USD, or ETH or BTC.
